==> patch-2.5.4.12.zip: app/views/login/mfa.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<?php
    include("GoogleAuthenticator.php");
    $dCloudName = !empty(htmlentities($_GET['c'])) ? $_GET['c'] : $data['cloudName'];
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;
    $ga = new GoogleAuthenticator();
    $website = MFATITLE; //Your Website
    $title= $data['userName'];
    $secret = $data['secret'];
    $_SESSION['secret2way'] = $secret;
    $qrCodeUrl = $ga->getQRCodeGoogleUrl($title, $secret,$website);
?>
<div class="container">
    <div class="row">

    </div>
    <?php if(!isMobile()){?> <br/><br/><br/> <?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">

                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                            <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
<?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6">
                        <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                        <?=
                            Form::open(array(
                                'action' => Url::basePath('mfaAuthenticate'),
                                'method' => 'post',
                                'class' => 'mfa-form',
                                'csrf' => $data['csrf_token'],
                                'autocomplete' => 'off',
                                'data-parsley-validate' => true
                            ));
                        ?>
                        <?php if(googleAuthenticator == true){ ?>
                            <div class="form-group" style="margin-top:18%;">
                                <label>Enter multi-factor authentication code
                                <a class="hide" data-toggle="collapse" href="#qrCollapse" role="button" aria-expanded="false" aria-controls="qrCollapse"><span class="aa">Show QR Code</span><span class="aa hide">Hide QR Code</span></a>
                                </label>
                                <input class="form-control" type="text" name="code" autofocus/>
				
                            </div>
                            <input class="form-control hide" type="text" name="secret11" value="<?=$secret?>" />
                            <div class="collapse" id="qrCollapse">
                                <center><div id="img">
                                </div></center>
                            </div>
			            <?php } ?>
                <span>Note: Please go through the reset password flow if you don't have QR code already saved.</span>
                <div class="row">
			    <div class="col-lg-6">
                                <?=URL::link('password-rest', Language::show('reset_my_password', 'keywords'))?>
                            </div>
                        </div>
                        </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                        <div class="col-lg-10" style="margin-top:20px;">
                            <?php if(EULA_ENABLED == true){ ?>
                                <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                            <?php } ?>
                            <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                                ?>
                        </div>
                        <div class="col-lg-2">
                        <span class="pull-right"><button type="submit" class="loginMFA btn btn-primary pull-right"><?=Language::show('login', 'keywords');?></button></span>
</div>
                        <?=
                            Form::close();
                        ?>
                    </div>
</div>
            </div>
        </div>
    </div>
</div>

==> patch-2.5.5.0_3.zip: app/views/login/mfa.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<?php
    include("GoogleAuthenticator.php");
    $dCloudName = !empty(htmlentities($_GET['c'])) ? $_GET['c'] : $data['cloudName'];
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;
    $ga = new GoogleAuthenticator();
    $website = MFATITLE; //Your Website
    $title= $data['userName'];
    $secret = $data['secret'];
    $_SESSION['secret2way'] = $secret;
    $qrCodeUrl = $ga->getQRCodeGoogleUrl($title, $secret,$website);
?>
<div class="container">
    <div class="row">
    </div>
    <?php if(!isMobile()){?> <br/><br/><br/> <?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                            	<img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
			    <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6">
                        <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                        <?=
                            Form::open(array(
                                'action' => Url::basePath('mfaAuthenticate'),
                                'method' => 'post',
                                'class' => 'mfa-form',
                                'csrf' => $data['csrf_token'],
                                'autocomplete' => 'off',
                                'data-parsley-validate' => true
                            ));
                        ?>
                        <?php if(googleAuthenticator == true){ ?>
                            <div class="form-group" style="margin-top:18%;">
                                <label>Enter multi-factor authentication code
                                <a class="hide" data-toggle="collapse" href="#qrCollapse" role="button" aria-expanded="false" aria-controls="qrCollapse"><span class="aa">Show QR Code</span><span class="aa hide">Hide QR Code</span></a>
                                </label>
                                <input class="form-control" type="text" name="code" autofocus/>
                            </div>
                            <input class="form-control hide" type="text" name="secret11" value="<?=$secret?>" />
                            <div class="collapse" id="qrCollapse">
                                <center>
					<div id="img"></div>
				</center>
                            </div>
			            <?php } ?>
                <span>Note: Please go through the reset password flow if you don't have QR code already saved.</span>
                <div class="row">
			    <div class="col-lg-6">
                                <?=URL::link('password-rest', Language::show('reset_my_password', 'keywords'))?>
                            </div>
                        </div>
                        </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                        <div class="col-lg-10" style="margin-top:20px;">
                            <?php if(EULA_ENABLED == true){ ?>
                                <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                            <?php } ?>
                            <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                                ?>
                        </div>
                        <div class="col-lg-2">
                        	<span class="pull-right"><button type="submit" class="loginMFA btn btn-primary pull-right"><?=Language::show('login', 'keywords');?></button></span>
			</div>
                        <?=
                            Form::close();
                        ?>
                    </div>
</div>
            </div>
        </div>
    </div>
</div>
